==> ejc-panhuo-impl-3.0.0-20200819.095054-19-sources.jar: com/ejianc/business/panhuo/service/impl/OrderServiceImpl.java <==
package com.ejianc.business.panhuo.service.impl;

import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.ejianc.business.panhuo.bean.GoodsEntity;
import com.ejianc.business.panhuo.bean.OrderEntity;
import com.ejianc.business.panhuo.mapper.OrderMapper;
import com.ejianc.business.panhuo.service.IGoodsService;
import com.ejianc.business.panhuo.service.IOrderService;
import com.ejianc.business.panhuo.vo.OrderVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.DateFormater;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;

/**
 * 订单实体
 * 
 * @author generator
 * 
 */
@Service("orderService")
public class OrderServiceImpl extends BaseServiceImpl<OrderMapper, OrderEntity> implements IOrderService{

    private static final String PANHUO_DD = "PANHUO_DD";

    @Autowired
    private IBillCodeApi billCodeApi;

    @Autowired
    private IGoodsService goodsService;

    @Override
    public OrderVO saveOrder(OrderVO vo) {
        Long tenantId = InvocationInfoProxy.getTenantid();
        GoodsEntity goodsEntity = goodsService.selectById(vo.getGoodsId());
        OrderEntity orderEntity = BeanMapper.map(vo,OrderEntity.class);
        orderEntity.setToolId(goodsEntity.getToolId());
        orderEntity.setTenantId(tenantId);
        orderEntity.setMaterialId(goodsEntity.getMaterialId());
        orderEntity.setMaterialName(goodsEntity.getMaterialName());
        orderEntity.setMaterialTypeId(goodsEntity.getMaterialTypeId());
        orderEntity.setMaterialTypeName(goodsEntity.getMaterialTypeName());
        orderEntity.setSystemId(goodsEntity.getSystemId());
        orderEntity.setSourceId(goodsEntity.getSourceId());
        orderEntity.setSpec(goodsEntity.getSpec());
        orderEntity.setMainimgPath(goodsEntity.getMainimgPath());
        orderEntity.setUnit(goodsEntity.getUnit());
        orderEntity.setType(0);//待确认
        orderEntity.setIsPack(goodsEntity.getIsPack());
        orderEntity.setSeller(goodsEntity.getSeller());
        orderEntity.setSellerName(goodsEntity.getSellerName());
        orderEntity.setSellAddress(goodsEntity.getAddress());
        orderEntity.setSellAddressId(goodsEntity.getAddressId());
        orderEntity.setSellOrg(goodsEntity.getOrgId());
        orderEntity.setSellOrgName(goodsEntity.getOrgName());
        orderEntity.setSellProject(goodsEntity.getProjectId());
        orderEntity.setSellProjectName(goodsEntity.getProjectName());
        orderEntity.setSellPhone(goodsEntity.getPhone());
        orderEntity.setSellUserName(goodsEntity.getName());
        orderEntity.setBuyTime(DateFormater.getCurrentDate());
        if(null!=vo&&StringUtils.isEmpty(vo.getBillCode())){
            CommonResponse<String> billCode = billCodeApi.getCodeBatchByRuleCode(PANHUO_DD,tenantId);
            if(billCode.isSuccess()) {
                orderEntity.setBillCode(billCode.getData());
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
//        BigDecimal nums = goodsEntity.getNums()==null?BigDecimal.ZERO:goodsEntity.getNums();
//        BigDecimal sellNums = goodsEntity.getSellNums()==null?BigDecimal.ZERO:goodsEntity.getSellNums();
        BigDecimal preNums = goodsEntity.getPreNums()==null?BigDecimal.ZERO:goodsEntity.getPreNums();
        BigDecimal rotatableNums = goodsEntity.getRotatableNums()==null?BigDecimal.ZERO:goodsEntity.getRotatableNums();
        goodsEntity.setPreNums(preNums.add(vo.getOrdernums()));
        goodsEntity.setRotatableNums(rotatableNums.subtract(vo.getOrdernums()));
        goodsService.saveOrUpdate(goodsEntity,false);

        super.saveOrUpdate(orderEntity, false);
        OrderVO resvo = BeanMapper.map(orderEntity, OrderVO.class);
        return resvo;
    }

    @Override
    public String confirmerOrder(OrderVO vo) {
        GoodsEntity goodsEntity = goodsService.selectById(vo.getGoodsId());
        OrderEntity orderEntity = super.getById(vo.getId());
        BigDecimal nums = goodsEntity.getNums()==null?BigDecimal.ZERO:goodsEntity.getNums();
        BigDecimal sellNums = goodsEntity.getSellNums()==null?BigDecimal.ZERO:goodsEntity.getSellNums();
        BigDecimal preNums = goodsEntity.getPreNums()==null?BigDecimal.ZERO:goodsEntity.getPreNums();
        BigDecimal remainingNums = goodsEntity.getRemainingNums()==null?BigDecimal.ZERO:goodsEntity.getRemainingNums();//剩余

        goodsEntity.setSellNums(sellNums.add(vo.getNums()));//已成交
        goodsEntity.setPreNums(preNums.subtract(orderEntity.getOrdernums()));//预定中
        goodsEntity.setRotatableNums(nums.subtract(goodsEntity.getSellNums()).subtract(goodsEntity.getPreNums()));//可周转
        goodsEntity.setRemainingNums(nums.subtract(goodsEntity.getSellNums()));//剩余数量
        if(BigDecimal.ZERO.compareTo(goodsEntity.getRemainingNums())>=0){
            //需下架
            goodsEntity.setStatus(1);//下架
            goodsEntity.setLowerType(1);//下架类型0-手动下架，1-售罄下架，2-到期下架
            goodsEntity.setLower(InvocationInfoProxy.getUserid());
            goodsEntity.setLowerTime(DateFormater.getCurrentDate());
        }
        goodsService.saveOrUpdate(goodsEntity,false);
        orderEntity.setConfirmer(vo.getConfirmer());
        orderEntity.setConfirmName(vo.getConfirmName());
        orderEntity.setPrice(vo.getPrice());
        orderEntity.setNums(vo.getNums());
        orderEntity.setMny(vo.getMny());
        orderEntity.setDealrTime(DateFormater.getCurrentDate());
        orderEntity.setType(1);//订单完成
        super.saveOrUpdate(orderEntity, false);
        return "success";
    }
}

==> ejc-panhuo-impl-3.0.0-20200824.065436-32-sources.jar: com/ejianc/business/panhuo/service/impl/OrderServiceImpl.java <==
package com.ejianc.business.panhuo.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.panhuo.bean.GoodsEntity;
import com.ejianc.business.panhuo.bean.OrderEntity;
import com.ejianc.business.panhuo.mapper.OrderMapper;
import com.ejianc.business.panhuo.service.IGoodsService;
import com.ejianc.business.panhuo.service.IOrderService;
import com.ejianc.business.panhuo.vo.OrderVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.DateFormater;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;

/**
 * 订单实体
 * 
 * @author generator
 * 
 */
@Service("orderService")
public class OrderServiceImpl extends BaseServiceImpl<OrderMapper, OrderEntity> implements IOrderService{

    private static final String PANHUO_DD = "PANHUO_DD";

    @Autowired
    private IBillCodeApi billCodeApi;

    @Autowired
    private IGoodsService goodsService;

    @Override
    public OrderVO saveOrder(OrderVO vo) {
        Long tenantId = InvocationInfoProxy.getTenantid();
        GoodsEntity goodsEntity = goodsService.selectById(vo.getGoodsId());
        BigDecimal rotatableNums = goodsEntity.getRotatableNums()==null?BigDecimal.ZERO:goodsEntity.getRotatableNums();
        BigDecimal ordernums = vo.getOrdernums()==null?BigDecimal.ZERO:vo.getOrdernums();
        if(ordernums.compareTo(rotatableNums)>0){
            throw new BusinessException("下单数量不能超过资产可周转数量!");
        }

        OrderEntity orderEntity = BeanMapper.map(vo,OrderEntity.class);
        orderEntity.setToolId(goodsEntity.getToolId());
        orderEntity.setTenantId(tenantId);
        orderEntity.setMaterialCode(goodsEntity.getMaterialCode());
        orderEntity.setMaterialId(goodsEntity.getMaterialId());
        orderEntity.setMaterialName(goodsEntity.getMaterialName());
        orderEntity.setMaterialTypeId(goodsEntity.getMaterialTypeId());
        orderEntity.setMaterialTypeName(goodsEntity.getMaterialTypeName());
        orderEntity.setSystemId(goodsEntity.getSystemId());
        orderEntity.setSourceId(goodsEntity.getSourceId());
        orderEntity.setSpec(goodsEntity.getSpec());
        orderEntity.setMainimgPath(goodsEntity.getMainimgPath());
        orderEntity.setUnit(goodsEntity.getUnit());
        orderEntity.setType(0);//待确认
        orderEntity.setIsPack(goodsEntity.getIsPack());
        orderEntity.setSeller(goodsEntity.getSeller());
        orderEntity.setSellerName(goodsEntity.getSellerName());
        orderEntity.setSellAddress(goodsEntity.getAddress());
        orderEntity.setSellAddressId(goodsEntity.getAddressId());
        orderEntity.setSellOrg(goodsEntity.getOrgId());
        orderEntity.setSellOrgName(goodsEntity.getOrgName());
        orderEntity.setSellProject(goodsEntity.getProjectId());
        orderEntity.setSellProjectName(goodsEntity.getProjectName());
        orderEntity.setSellPhone(goodsEntity.getPhone());
        orderEntity.setSellUserName(goodsEntity.getName());
        orderEntity.setBuyTime(DateFormater.getCurrentDate());
        orderEntity.setMny(vo.getOrdermny()==null?BigDecimal.ZERO:vo.getOrdermny());
        orderEntity.setPrice(vo.getOrderprice()==null?BigDecimal.ZERO:vo.getOrderprice());
        orderEntity.setNums(vo.getOrdernums()==null?BigDecimal.ZERO:vo.getOrdernums());
        orderEntity.setOriginalprice(goodsEntity.getOriginalprice());
        orderEntity.setDiscount(goodsEntity.getDiscount());
        if(null!=vo&&StringUtils.isEmpty(vo.getBillCode())){
            CommonResponse<String> billCode = billCodeApi.getCodeBatchByRuleCode(PANHUO_DD,tenantId);
            if(billCode.isSuccess()) {
                orderEntity.setBillCode(billCode.getData());
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
//        BigDecimal nums = goodsEntity.getNums()==null?BigDecimal.ZERO:goodsEntity.getNums();
//        BigDecimal sellNums = goodsEntity.getSellNums()==null?BigDecimal.ZERO:goodsEntity.getSellNums();
        BigDecimal preNums = goodsEntity.getPreNums()==null?BigDecimal.ZERO:goodsEntity.getPreNums();
        goodsEntity.setPreNums(preNums.add(vo.getOrdernums()));
        goodsEntity.setRotatableNums(rotatableNums.subtract(vo.getOrdernums()));
        goodsService.saveOrUpdate(goodsEntity,false);

        super.saveOrUpdate(orderEntity, false);
        OrderVO resvo = BeanMapper.map(orderEntity, OrderVO.class);
        return resvo;
    }

    @Override
    public String confirmerOrder(OrderVO vo) {
        GoodsEntity goodsEntity = goodsService.selectById(vo.getGoodsId());
        OrderEntity orderEntity = super.getById(vo.getId());
        BigDecimal nums = goodsEntity.getNums()==null?BigDecimal.ZERO:goodsEntity.getNums();
        BigDecimal sellNums = goodsEntity.getSellNums()==null?BigDecimal.ZERO:goodsEntity.getSellNums();
        BigDecimal preNums = goodsEntity.getPreNums()==null?BigDecimal.ZERO:goodsEntity.getPreNums();
        BigDecimal remainingNums = goodsEntity.getRemainingNums()==null?BigDecimal.ZERO:goodsEntity.getRemainingNums();//剩余

        goodsEntity.setSellNums(sellNums.add(vo.getNums()));//已成交
        goodsEntity.setPreNums(preNums.subtract(orderEntity.getOrdernums()));//预定中
        goodsEntity.setRotatableNums(nums.subtract(goodsEntity.getSellNums()).subtract(goodsEntity.getPreNums()));//可周转
        goodsEntity.setRemainingNums(nums.subtract(goodsEntity.getSellNums()));//剩余数量
        if(BigDecimal.ZERO.compareTo(goodsEntity.getRemainingNums())>=0){
            LambdaQueryWrapper<OrderEntity> lambdachange = Wrappers.<OrderEntity>lambdaQuery();
            lambdachange.eq(OrderEntity::getTenantId, InvocationInfoProxy.getTenantid());
            lambdachange.eq(OrderEntity::getGoodsId,vo.getGoodsId());
            lambdachange.eq(OrderEntity::getType,0);
            lambdachange.ne(OrderEntity::getId,vo.getId());
            int num = super.count(lambdachange);
            if(num<=0){
                //需下架
                goodsEntity.setStatus(1);//下架
                goodsEntity.setLowerType(1);//下架类型0-手动下架，1-售罄下架，2-到期下架
                goodsEntity.setLower(InvocationInfoProxy.getUserid());
                goodsEntity.setLowerTime(DateFormater.getCurrentDate());
            }
        }
        goodsService.saveOrUpdate(goodsEntity,false);
        orderEntity.setConfirmer(vo.getConfirmer());
        orderEntity.setConfirmName(vo.getConfirmName());
        orderEntity.setPrice(vo.getPrice());
        orderEntity.setNums(vo.getNums());
        orderEntity.setMny(vo.getMny());
        orderEntity.setDealrTime(DateFormater.getCurrentDate());
        orderEntity.setType(1);//订单完成
        super.saveOrUpdate(orderEntity, false);
        return "success";
    }
}
